Documentation
¶
Index ¶
- type Provider
- func (p *Provider) AppendRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- func (Provider) CaddyModule() caddy.ModuleInfo
- func (p *Provider) DeleteRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- func (p *Provider) GetRecords(ctx context.Context, zone string) ([]libdns.Record, error)
- func (p *Provider) Provision(ctx caddy.Context) error
- func (p *Provider) SetRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- func (p *Provider) UnmarshalCaddyfile(d *caddyfile.Dispenser) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct {
// ServerURL is the URL of the Bluecat Address Manager server
ServerURL string `json:"server_url,omitempty"`
// Username is the API username
Username string `json:"username,omitempty"`
// Password is the API password
Password string `json:"password,omitempty"`
// ConfigurationName is the name of the configuration to use
ConfigurationName string `json:"configuration_name,omitempty"`
// ViewName is the name of the view to use
ViewName string `json:"view_name,omitempty"`
// DeploymentBatchWindow coalesces same-zone quick deploys using a Caddy duration string
DeploymentBatchWindow string `json:"deployment_batch_window,omitempty"`
// contains filtered or unexported fields
}
Provider lets Caddy read and manipulate DNS records hosted by Bluecat Address Manager.
func (*Provider) AppendRecords ¶
func (p *Provider) AppendRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
AppendRecords adds records to the zone. It returns the records that were added.
func (Provider) CaddyModule ¶
func (Provider) CaddyModule() caddy.ModuleInfo
CaddyModule returns the Caddy module information.
func (*Provider) DeleteRecords ¶
func (p *Provider) DeleteRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
DeleteRecords deletes the specified records from the zone.
func (*Provider) GetRecords ¶
GetRecords lists all the records in the zone.
func (*Provider) SetRecords ¶
func (p *Provider) SetRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
SetRecords sets the records in the zone, either by updating existing records or creating new ones.
func (*Provider) UnmarshalCaddyfile ¶
UnmarshalCaddyfile sets up the DNS provider from Caddyfile tokens. Syntax:
bluecat {
server_url <url>
username <username>
password <password>
configuration_name <name> // optional
view_name <name> // optional
deployment_batch_window <duration> // optional
}
Click to show internal directories.
Click to hide internal directories.